#!/bin/bash

###########################################
# The CCseqBasic installation is located here :
pipePath="/t1-home/molhaem2/telenius/CCseqBasic/CS5/"
###########################################


# ___________________________________________
# Here we are giving our R1 and R2 fastq files 
# using PIPE_fastqPaths.txt parameter file,
# instead of using flags --R1 and --R2

# ___________________________________________
# This is the genome build for the run :

Genome="mm9"


# ___________________________________________
# capturesiteFile is the RE fragment coordinate input file (containing the dpnII fragments within which your biotinylated capture oligos are) :
# Make this file with this tutorial : http://userweb.molbiol.ox.ac.uk/public/telenius/CaptureCompendium/CCseqBasic/3_run/fragmentfile.html

capturesiteFile="/t1-data/user/hugheslab/telenius/runsAndAnalysis/captureCompendium_runsForPaper_271118/3_CCseqBasic/CCseqBasicFragmentFile.txt"


# ___________________________________________
# This is the path to the public folder we want to put the data into (this folder can exist, but it does not need to) :

PublicPath="/public/telenius/CaptureCompendium/CCseqBasic/3_run/30gRUNS"

# ___________________________________________
# This is the name we give our sample (no fancy characters, don't start the name with a number)

Sample="30g_es1"

# ___________________________________________
# This is the directory /REUSE_blat of a previous CCseqBasic run,
# probably ran with --onlyBlat flag , to speed up the actual analysis runs.
# To generate this folder, follow instructions in here : http://userweb.molbiol.ox.ac.uk/public/telenius/CaptureCompendium/CCseqBasic/3_run/onlyblat.html

# To not use this, leave the --BLATforREUSEfolderPath flag out of the command below
# or give '.' (i.e. "current directory") as the value of the flag (like below). 

# Example :
# reuseBLATdir="/t1-data/user/telenius/sample1/F4_blatPloidyFilteringLog_sample1_CS5/BlatPloidyFilterRun/REUSE_blat"

reuseBLATdir='/t1-data/user/hugheslab/telenius/runsAndAnalysis/captureCompendium_runsForPaper_271118/2_CCseqBasic_onlyBlat/BlatPloidyFilterRun/REUSE_blat'


#############################################
# We are now here (the current directory) - the directory we are now running the pipe :

rundir=$( pwd )


# Tell where we are - print it to output :

echo "Running CCseqBasic5.sh in folder ${rundir}"


# Tell the command to user - print it to output :

echo "${pipePath}/CCseqBasic5.sh -c ${capturesiteFile} -s ${Sample} --pf ${PublicPath} --genome ${Genome} --chunkmb 1012 --BLATforREUSEfolderPath ${reuseBLATdir} --gz --SRR "


# Run the command :

${pipePath}/CCseqBasic5.sh -c "${capturesiteFile}" -s "${Sample}" --pf "${PublicPath}" --genome ${Genome} --chunkmb 1012 --BLATforREUSEfolderPath ${reuseBLATdir} --gz --SRR



# Tell the user that we are now finished :

echo "All done !"

